==> curses-snake-1.0.2.tar.gz: curses-snake-1.0.2/setup.py <==
from setuptools import find_packages
import os
from distutils.core import setup

# User-friendly description from README.md
current_directory = os.path.dirname(os.path.abspath(__file__))
try:
    with open(os.path.join(current_directory, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except Exception:
    long_description = ''

setup(
    # Name of the package
    name='curses-snake',
    # Packages to include into the distribution
    packages=find_packages('.'),
    # Start with a small number and increase it with
    # every change you make https://semver.org
    version='1.0.2',
    # Chose a license from here: https: //
    # help.github.com / articles / licensing - a -
    # repository. For example: MIT
    license='MIT',
    # Short description of your library
    description='Snake game in console based on cureses.',
    # Long description of your library
    long_description=long_description,
    long_description_content_type='text/markdown',
    # Your name
    author='voilalex',
    # Your email
    author_email='ilya.vouk@gmail.com',
    # Either the link to your github or to your website
    url='https://github.com/VoIlAlex',
    # Link from which the project can be downloaded
    download_url='https://github.com/VoIlAlex/curses-snake/archive/v1.0.2.tar.gz',
    # List of keywords
    keywords=[
        'game', 'console', 'curses', 'snake'
    ],
    # List of packages to install with this one
    install_requires=[
        'cursy'
    ],
    # https://pypi.org/classifiers/
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console :: Curses',
        'Topic :: Games/Entertainment',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8'
    ],
    entry_points="""
    [console_scripts]
    curses-snake = curses_snake.cli:cli
    """,
    zip_safe=False
)

==> curses-snake-1.0.3.tar.gz: curses-snake-1.0.3/setup.py <==
from setuptools import find_packages
import os
from distutils.core import setup

# User-friendly description from README.md
current_directory = os.path.dirname(os.path.abspath(__file__))
try:
    with open(os.path.join(current_directory, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except Exception:
    long_description = ''

setup(
    # Name of the package
    name='curses-snake',
    # Packages to include into the distribution
    packages=find_packages('.'),
    # Start with a small number and increase it with
    # every change you make https://semver.org
    version='1.0.3',
    # Chose a license from here: https: //
    # help.github.com / articles / licensing - a -
    # repository. For example: MIT
    license='MIT',
    # Short description of your library
    description='Snake game in console based on cureses.',
    # Long description of your library
    long_description=long_description,
    long_description_content_type='text/markdown',
    # Your name
    author='voilalex',
    # Your email
    author_email='ilya.vouk@gmail.com',
    # Either the link to your github or to your website
    url='https://github.com/VoIlAlex/curses-snake',
    # Link from which the project can be downloaded
    download_url='https://github.com/VoIlAlex/curses-snake/archive/v1.0.3.tar.gz',
    # List of keywords
    keywords=[
        'game', 'console', 'curses', 'snake'
    ],
    # List of packages to install with this one
    install_requires=[
        'cursy'
    ],
    # https://pypi.org/classifiers/
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console :: Curses',
        'Topic :: Games/Entertainment',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8'
    ],
    entry_points="""
    [console_scripts]
    curses-snake = curses_snake.cli:cli
    """,
    zip_safe=False
)
